@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2007 Quentin Sculo <squentin@free.fr>
+# Copyright (C) 2005-2008 Quentin Sculo <squentin@free.fr>
 #
 # This file is part of Gmusicbrowser.
 # Gmusicbrowser is free software; you can redistribute it and/or modify
@@ -33,8 +33,8 @@ my %Sites=
  {	googlei => ['google images',"http://images.google.com/images?q=%s&imgsz=medium|large", \&parse_googlei],
 	slothradio => ['slothradio', "http://www.slothradio.com/covers/?artist=%a&album=%l", \&parse_sloth],
 	#itunesgrabber => ['itunesgrabber',"http://www.thejosher.net/iTunes/index.php?artist=%a&album=%l", \&parse_itunesgrabber],
-	freecovers => ['freecovers.net', "http://www.freecovers.net/search.php?search=%s&cat=4", \&parse_freecovers],
-	rateyourmusic=> ['rateyourmusic.com', "http://rateyourmusic.com/search?searchterm=%s&searchtype=l",\&parse_rateyourmusic],
+	freecovers => ['freecovers.net', "http://www.freecovers.net/api/search/%s", \&parse_freecovers], #could add /Music+CD but then we'd lose /Soundtrack
+	#rateyourmusic=> ['rateyourmusic.com', "http://rateyourmusic.com/search?searchterm=%s&searchtype=l",\&parse_rateyourmusic], # urls results in "403 Forbidden"
  },
 );
 
@@ -239,24 +239,30 @@ sub parse_rateyourmusic
 	}
 	return \@list;
 }
-sub parse_freecovers
+sub parse_freecovers #FIXME could use a XML module	#can provide backcover and more too
 {	my $result=$_[0];
 	my @list;
-	#while ($result=~m#href=http://www\.freecovers\.net/view/([^>]+)>Front#g)
-	while ($result=~m#href=http://www\.freecovers\.net/view/(0/[^/]+)(/[^>]+)>Front#g)
-	{	push @list,
-		{	url=> "http://www.freecovers.net/download/$1$2%5D-%5Bwww.FreeCovers.net%5D.jpg",
-			previewurl => "http://www.freecovers.net/thumb/$1/front.jpg",
-		};
+	while ($result=~m#<title>(.+?)</title>#gs)
+	{	my $res=$1;
+		my %res;
+		$res{desc}= ::decode_html(Encode::decode('cp1252',$1)) if $res=~m#<name>([^<]+)</name>#; #FIXME not sure of the encoding
+		while ($res=~m#<cover>(.+?)</cover>#gs)
+		{	my $res=$1;
+			next unless $res=~m#<type>front</type>#;
+			$res{url}=$1 if $res=~m#<preview>([^<]+)</preview>#;
+			$res{previewurl}=$1 if $res=~m#<thumbnail>([^<]+)</thumbnail>#;
+			last;
+		}
+		push @list, \%res if $res{url};
 	}
 	return \@list;
 }
 sub parse_lastfm
 {	my $result=$_[0];
 	my @list;
-	while ($result=~m#<a href="/music/[^"]+/\+images/\d+"[^>]+class="pic[^<]+<img src="([^"]+)"#gs)
+	while ($result=~m#<a href="/music/[^/]+/\+images/\d+"[^>]+?class="pic".+?<img [^>]+?src="([^"]+)"#gs)
 	{	my $url=my $pre=$1;
-		$url=~s#/\d+/(\d+.jpg)$#/_/$1#; ### /160/123456.jpg -> /_/123456.jpg
+		$url=~s#/\w+/(\d+.jpg)$#/_/$1#; ### /126b/123456.jpg -> /_/123456.jpg
 		push @list, {url => $url, previewurl =>$pre,};
 	}
 	my $nexturl;
