@@ -165,7 +165,7 @@ sub SongChanged
 	my $ref=$::Songs[$ID];
 	my $title=$ref->[::SONG_TITLE];
 	my $artist=$ref->[::SONG_ARTIST];
-	s/([^A-Za-z0-9-])/sprintf('%%%02X', ord($1))/eg for $title,$artist;
+	$_=::url_escapeall($_) for $title,$artist;
 	my (undef,$url,$post,$check)=@{$sites{$::Options{OPT.'LyricSite'}}};
 	for ($url,$post) { next unless defined $_; s/%a/$artist/; s/%s/$title/; }
 	#$self->load_url($url,$post);
